import { Driver } from "./Driver";
import { SchemaBuilder } from "../schema-builder/SchemaBuilder";
import { BaseDriver } from "./BaseDriver";
import { ConnectionOptions } from "../connection/ConnectionOptions";
/**
 * This driver organizes work with postgres database.
 */
export declare class PostgresDriver extends BaseDriver implements Driver {
    /**
     * Connection used in this driver.
     */
    connectionOptions: ConnectionOptions;
    /**
     * Postgres library.
     */
    private postgres;
    /**
     * Connection to postgres database.
     */
    private postgresConnection;
    /**
     * Access to the native implementation of the database.
     */
    readonly native: any;
    /**
     * Access to the native connection to the database.
     */
    readonly nativeConnection: any;
    /**
     * Database name to which this connection is made.
     */
    readonly db: string;
    constructor(postgres?: any);
    /**
     * Creates a schema builder which can be used to build database/table schemas.
     */
    createSchemaBuilder(): SchemaBuilder;
    /**
     * Performs connection to the database based on given connection options.
     */
    connect(): Promise<void>;
    /**
     * Closes connection with database.
     */
    disconnect(): Promise<void>;
    /**
     * Escapes given value.
     */
    escape(value: any): any;
    /**
     * Executes a given SQL query.
     */
    query<T>(query: string): Promise<T>;
    /**
     * Clears all tables in the currently connected database.
     */
    clearDatabase(): Promise<void>;
    protected checkIfConnectionSet(): void;
}
