import { TargetMetadata } from "./TargetMetadata";
import { EntityMetadata } from "./EntityMetadata";
import { TableMetadataArgs } from "../metadata-args/TableMetadataArgs";
/**
 * Table type.
 */
export declare type TableType = "regular" | "abstract" | "junction" | "closure" | "closureJunction" | "embeddable";
/**
 * This metadata interface contains all information about specific table.
 */
export declare class TableMetadata extends TargetMetadata {
    /**
     * Naming strategy used to generate and normalize table name.
     */
    entityMetadata: EntityMetadata;
    /**
     * Indicates if this table is abstract or not. Regular tables can inherit columns from abstract tables.
     */
    private readonly tableType;
    /**
     * Table name in the database.
     */
    private readonly _name;
    /**
     * Array of properties that will be used in a composite primary key of the table.
     */
    private readonly primaryKeys;
    /**
     * A property name by which queries will perform ordering by default when fetching rows.
     */
    private readonly orderBy;
    constructor(args: TableMetadataArgs);
    /**
     * Table name in the database.
     */
    readonly name: string;
    /**
     * Checks if this table is regular (non abstract and non closure).
     */
    readonly isRegular: boolean;
    /**
     * Checks if this table is abstract.
     */
    readonly isAbstract: boolean;
    /**
     * Checks if this table is a closure table.
     */
    readonly isClosure: boolean;
    /**
     * Checks if this table is a junction table of the closure table.
     */
    readonly isClosureJunction: boolean;
    /**
     * Checks if this table is an embeddable table.
     */
    readonly isEmbeddable: boolean;
}
