"use strict";
const ReactiveRepository_1 = require("./ReactiveRepository");
const Rx = require("rxjs/Rx");
/**
 * Tree repository is supposed to work with your entity objects. Find entities, insert, update, delete, etc.
 * This version of TreeRepository is using rxjs library and Observables instead of promises.
 */
class ReactiveTreeRepository extends ReactiveRepository_1.ReactiveRepository {
    // -------------------------------------------------------------------------
    // Constructor
    // -------------------------------------------------------------------------
    constructor(repository) {
        super(repository);
        this.repository = repository;
    }
    // -------------------------------------------------------------------------
    // Public Methods
    // -------------------------------------------------------------------------
    /**
     * Roots are entities that have no ancestors. Finds them all.
     */
    findRoots() {
        return Rx.Observable.fromPromise(this.repository.findRoots());
    }
    /**
     * Creates a query builder used to get descendants of the entities in a tree.
     */
    createDescendantsQueryBuilder(alias, closureTableAlias, entity) {
        return this.repository.createDescendantsQueryBuilder(alias, closureTableAlias, entity);
    }
    /**
     * Gets all children (descendants) of the given entity. Returns them all in a flat array.
     */
    findDescendants(entity) {
        return Rx.Observable.fromPromise(this.repository.findDescendants(entity));
    }
    /**
     * Gets all children (descendants) of the given entity. Returns them in a tree - nested into each other.
     */
    findDescendantsTree(entity) {
        return Rx.Observable.fromPromise(this.repository.findDescendantsTree(entity));
    }
    /**
     * Gets number of descendants of the entity.
     */
    countDescendants(entity) {
        return Rx.Observable.fromPromise(this.repository.countDescendants(entity));
    }
    /**
     * Creates a query builder used to get ancestors of the entities in the tree.
     */
    createAncestorsQueryBuilder(alias, closureTableAlias, entity) {
        return this.repository.createAncestorsQueryBuilder(alias, closureTableAlias, entity);
    }
    /**
     * Gets all parents (ancestors) of the given entity. Returns them all in a flat array.
     */
    findAncestors(entity) {
        return Rx.Observable.fromPromise(this.repository.findAncestors(entity));
    }
    /**
     * Gets all parents (ancestors) of the given entity. Returns them in a tree - nested into each other.
     */
    findAncestorsTree(entity) {
        return Rx.Observable.fromPromise(this.repository.findAncestorsTree(entity));
    }
    /**
     * Gets number of ancestors of the entity.
     */
    countAncestors(entity) {
        return Rx.Observable.fromPromise(this.repository.countAncestors(entity));
    }
}
exports.ReactiveTreeRepository = ReactiveTreeRepository;
//# sourceMappingURL=ReactiveTreeRepository.js.map