"use strict";
const fs = require("fs");
const path = require("path");
/**
 * Loads all exported classes from the given directory.
 * @internal
 */
class DirectoryExportedClassesLoader {
    // todo: this can be extracted into external module and used across all other modules
    // -------------------------------------------------------------------------
    // Public Methods
    // -------------------------------------------------------------------------
    /**
     * Imports all entities (makes them "require") from the given directories.
     */
    importClassesFromDirectories(directories) {
        const allDirectories = directories.reduce((allDirs, dir) => {
            return allDirs.concat(require("glob").sync(path.normalize(dir)));
        }, []);
        const requireAll = require("require-all");
        const filter = /(.*)\.(js)$/;
        // const filter = /(.*)\.(js|ts)$/;
        const dirs = allDirectories
            .filter(directory => fs.existsSync(directory))
            .map(directory => requireAll({ dirname: directory, filter: filter, recursive: true }));
        return this.loadFileClasses(dirs, []);
    }
    importJsonsFromDirectories(directories) {
        const allDirectories = directories.reduce((allDirs, dir) => {
            return allDirs.concat(require("glob").sync(path.normalize(dir)));
        }, []);
        const requireAll = require("require-all");
        const filter = /(.*)\.json$/;
        const loaded = allDirectories
            .filter(directory => fs.existsSync(directory))
            .map(directory => requireAll({ dirname: directory, filter: filter, recursive: true }));
        const flattened = [];
        loaded.forEach(file => Object.keys(file).forEach(key => {
            flattened.push(file[key]);
        }));
        return flattened;
    }
    // -------------------------------------------------------------------------
    // Private Methods
    // -------------------------------------------------------------------------
    loadFileClasses(exported, allLoaded) {
        if (exported instanceof Function) {
            allLoaded.push(exported);
        }
        else if (exported instanceof Object) {
            Object.keys(exported).forEach(key => this.loadFileClasses(exported[key], allLoaded));
        }
        else if (exported instanceof Array) {
            exported.forEach((i) => this.loadFileClasses(i, allLoaded));
        }
        return allLoaded;
    }
}
exports.DirectoryExportedClassesLoader = DirectoryExportedClassesLoader;
function importClassesFromDirectories(directories) {
    const loader = new DirectoryExportedClassesLoader();
    return loader.importClassesFromDirectories(directories);
}
exports.importClassesFromDirectories = importClassesFromDirectories;
function importJsonsFromDirectories(directories) {
    const loader = new DirectoryExportedClassesLoader();
    return loader.importJsonsFromDirectories(directories);
}
exports.importJsonsFromDirectories = importJsonsFromDirectories;
//# sourceMappingURL=DirectoryExportedClassesLoader.js.map